@@ -89,29 +89,6 @@ class OrderService:
         """
         return self.__client.call("eleme.order.noMoreDeliveryLite", {"orderId": order_id})
 
-    def received_order_lite(self, order_id):
-        """
-        订单确认送达
-        :param orderId:订单Id
-        """
-        return self.__client.call("eleme.order.receivedOrderLite", {"orderId": order_id})
-
-    def start_delivery_by_self(self, order_id, phone):
-        """
-        订单确认送出(自配送)
-        :param orderId:订单Id
-        :param phone:配送者电话
-        """
-        return self.__client.call("eleme.order.startDeliveryBySelf", {"orderId": order_id, "phone": phone})
-
-    def complete_delivery_by_self(self, order_id, phone):
-        """
-        订单确认送达(自配送)
-        :param orderId:订单Id
-        :param phone:配送者电话
-        """
-        return self.__client.call("eleme.order.completeDeliveryBySelf", {"orderId": order_id, "phone": phone})
-
     def reply_reminder(self, remind_id, type, content):
         """
         回复催单
@@ -276,6 +253,15 @@ class OrderService:
         """
         return self.__client.call("eleme.order.applyRefund", {"orderId": order_id, "type": type, "remark": remark})
 
+    def shop_pay_apply_refund(self, order_id, type, remark):
+        """
+        商家主动发起退单（企业到店买单订单）
+        :param orderId:订单Id
+        :param type:取消原因
+        :param remark:备注说明
+        """
+        return self.__client.call("eleme.order.shopPayApplyRefund", {"orderId": order_id, "type": type, "remark": remark})
+
     def set_order_prepared(self, order_id):
         """
         非自配送餐厅标记已出餐
@@ -361,3 +347,54 @@ class OrderService:
         """
         return self.__client.call("eleme.order.queryCallAvailable", {"orderId": order_id})
 
+    def batch_get_refund_orders(self, order_ids):
+        """
+        批量获取订单退款信息V2
+        :param orderIds:订单Id列表
+        """
+        return self.__client.call("eleme.order.batchGetRefundOrders", {"orderIds": order_ids})
+
+    def query_refund_amount_info(self, order_id):
+        """
+        获取订单退款金额分摊明细信息
+        :param orderId:订单Id
+        """
+        return self.__client.call("eleme.order.queryRefundAmountInfo", {"orderId": order_id})
+
+    def query_cooking_time_config(self, shop_id):
+        """
+        查询店铺订单出餐时长和推荐出餐时长
+        :param shopId:店铺Id
+        """
+        return self.__client.call("eleme.order.queryCookingTimeConfig", {"shopId": shop_id})
+
+    def set_peak_period_cooking_time(self, shop_id, configs):
+        """
+        设置店铺高峰期出餐时长
+        :param shopId:店铺Id
+        :param configs:高峰期出餐时长配置
+        """
+        return self.__client.call("eleme.order.setPeakPeriodCookingTime", {"shopId": shop_id, "configs": configs})
+
+    def set_non_peak_period_cooking_time(self, shop_id, config):
+        """
+        设置店铺非高峰期出餐时长
+        :param shopId:店铺Id
+        :param config:非高峰期出餐配置
+        """
+        return self.__client.call("eleme.order.setNonPeakPeriodCookingTime", {"shopId": shop_id, "config": config})
+
+    def set_delay_cooking_time_setting(self, request):
+        """
+        商户设置延长出餐
+        :param request:延长出餐时长
+        """
+        return self.__client.call("eleme.order.setDelayCookingTimeSetting", {"request": request})
+
+    def batch_get_order_address(self, order_ids):
+        """
+        批量获取订单地址
+        :param orderIds:查询订单对应地址信息
+        """
+        return self.__client.call("eleme.order.batchGetOrderAddress", {"orderIds": order_ids})
+
